@@ -9,7 +9,7 @@
     @Copyright (c) 2016-2017
 */
 
-const work_dir = process.cwd();
+
 var stream = require('stream');
 const java = require('java');
 const fs = require('fs');
@@ -17,9 +17,10 @@ const fs = require('fs');
 
 module.exports = function (app) {
     var work_dir = app.nylon.work_dir;
-    app.use(function (req, res, next) {
+   // app.use(function (req, res, next) {
 
-        res.ireport = function (reportName, type, datas, parameters) {
+        app.nylon.res.ireport = function (reportName, type, datas, parameters) {
+            var self=this;
             var types=type.split("|");
            // console.log(types);
             type=types[0];
@@ -48,28 +49,30 @@ module.exports = function (app) {
             rp.export(reportName, type, JSON.stringify(datas), JSON.stringify(parameters),
                 function (err, buff) {
                     if (err) {
-                        res.send(err);
+                        self.send(err);
                     } else {
                         var buffer = Buffer.from(buff, "hex");
-                        res.responseFile(buffer, type,saved);
+                        self.responseFile(buffer, type,saved);
                     }
 
                 }
             );
         }
 
-        res.responseFile = function (buffer, type,saved) {
+        app.nylon.res.responseFile = function (buffer, type,saved) {
+
+            var self=this;
+            var fname = self._guid()+self._getFileExtension(type);
 
-            var fname = req._guid()+req._getFileExtension(type);
             console.log(fname);
 
             if (saved) {
-                var stream = fs.createWriteStream(work_dir + "/tmp/" + fname);
-                stream.end(buffer);
-                res.send(fname)
+                var streamx = fs.createWriteStream(work_dir + "/tmp/" + fname);
+                streamx.end(buffer);
+                self.send(fname)
             } else {
 
-
+              
 
 
 
@@ -108,11 +111,11 @@ module.exports = function (app) {
                     this.setHeader('Content-Type', 'application/pdf');
                     this.setHeader('Content-Disposition', 'attachment; filename=' + fname );
                 }
-                bufferStream.pipe(this);
+                bufferStream.pipe(self);
             }
         }
 
-        req._getFileExtension=function(type){
+        app.nylon.res._getFileExtension=function(type){
             if (type == "pdf") {
                return ".pdf";
             } else if (type == 'excel') {
@@ -134,7 +137,7 @@ module.exports = function (app) {
             }
         }
 
-        req._guid = function () {
+        app.nylon.res._guid = function () {
             function s4() {
                 return Math.floor((1 + Math.random()) * 0x10000)
                     .toString(16)
@@ -144,9 +147,9 @@ module.exports = function (app) {
                 s4() + '-' + s4() + s4() + s4();
         }
 
-        next();
+      //  next();
 
-    });
+   // });
 
 
 
